Signature

Struct Signature 

#[repr(C)]
pub struct Signature { pub(crate) R: [u8; 57], pub(crate) s: [u8; 57], }
Ed448 signature.

This type represents a container for the byte serialization of an Ed448 signature, and does not necessarily represent well-formed field or curve elements.

Signature verification libraries are expected to reject invalid field elements at the time a signature is verified.

Fields

R: [u8; 57]s: [u8; 57]

Implementations

Source

impl Signature

pub const BYTE_SIZE: usize

Size of an encoded Ed448 signature in bytes (114-bytes).

pub fn from_bytes(bytes: &[u8; 114]) -> Signature

Parse an Ed448 signature from a byte slice.

pub fn from_slice(bytes: &[u8]) -> Result<Signature, Error>

Parse an Ed448 signature from a byte slice.

Errors
  • Returns Error if the input byte slice is not 114-bytes.
pub fn r_bytes(&self) -> &[u8; 57]

Bytes for the R component of a signature.

pub fn s_bytes(&self) -> &[u8; 57]

Bytes for the s component of a signature.

pub fn to_bytes(&self) -> [u8; 114]

Return the inner byte array.

pub fn from_components( r: impl Into<[u8; 57]>, s: impl Into<[u8; 57]>, ) -> Signature

Create a Signature from the serialized r and s component values which comprise the signature.